@@ -339,11 +339,18 @@ main (gint argc, gchar **argv)
 
   if (desktop_name == NULL)
     {
-      application_info = unity_webapps_application_info_new (name, domain, icon_url, mime_types);
+      application_info = unity_webapps_application_info_new (name,
+                                                             domain,
+                                                             icon_url,
+                                                             mime_types);
     }
   else
     {
-      application_info = unity_webapps_preinstalled_application_info_new (name, domain, icon_url, mime_types, desktop_name);
+      application_info = unity_webapps_preinstalled_application_info_new (name,
+                                                                          domain,
+                                                                          icon_url,
+                                                                          mime_types,
+                                                                          desktop_name);
     }
   
   wnck_set_client_type (WNCK_CLIENT_TYPE_PAGER);
