@@ -764,6 +764,8 @@ on_handle_get_context (UnityWebappsGenService *service_interface,
   return TRUE;
 }
 
+#if 0
+
 static gchar*
 _firefox_profile_get_name_for_app (const gchar *homepage)
 {
@@ -958,6 +960,7 @@ _firefox_get_profile_for_app (const gchar *homepage)
 
   return res;
 }
+#endif
 
 /**
  *
@@ -976,12 +979,14 @@ get_browser_command_line_format (const gchar *homepage)
 
   if (g_str_has_suffix (exe_name, "firefox"))
     {
-      /*      gchar *profile_path = _firefox_get_profile_for_app (homepage);
+#if 0
+      gchar *profile_path = _firefox_get_profile_for_app (homepage);
 
       if (profile_path)
 	{
 	  return g_strdup_printf ("%s --chromeless -no-remote -profile %s '%%s'", exe_name, profile_path);
-	  }*/
+        }
+#endif
       return g_strdup_printf ("%s --new-window '%%s'", exe_name);
     }
   return g_strdup_printf ("%s --chromeless --new-window '%%s'", exe_name);
